==> sqlitestudio-3.0.7.tar.gz: Plugins/SqlEnterpriseFormatter/SqlEnterpriseFormatter_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>QObject</name>
    <message>
        <location filename="sqlenterpriseformatter.cpp" line="91"/>
        <location filename="sqlenterpriseformatter.cpp" line="98"/>
        <source>name</source>
        <comment>example name wrapper</comment>
        <translation>имя</translation>
    </message>
</context>
<context>
    <name>SqlEnterpriseFormatter</name>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="46"/>
        <source>Indentation</source>
        <translation>Отступы</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="58"/>
        <source>Line up keywords in multi-line queries</source>
        <translation>Выравнивать ключевые слова в многострочных запросах</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="68"/>
        <source>Indent contents of parenthesis block</source>
        <translation>Выравнивать содержимое внутри скобок</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="91"/>
        <source>Tab size:</source>
        <translation>Шаг табуляции:</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="106"/>
        <source>New lines</source>
        <translation>Переносы строк</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="160"/>
        <source>Before opening parenthesis in column definitions</source>
        <translation>Перед открывающей скобкой в определениях столбцов</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="170"/>
        <source>After opening parenthesis in column definitions</source>
        <translation>После открывающей скобки в определениях столбцов</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="180"/>
        <source>Before closing parenthesis in column definitions</source>
        <translation>Перед закрывающей скобкой в определениях столбцов</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="190"/>
        <source>After closing parenthesis in column definitions</source>
        <translation>После закрывающей скобки в определениях столбцов</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="200"/>
        <source>Before opening parenthesis in expressions</source>
        <translation>Перед открывающей скобкой в выражениях</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="210"/>
        <source>After opening parenthesis in expressions</source>
        <translation>После открывающей скобки в выражениях</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="220"/>
        <source>Before closing parenthesis in expressions</source>
        <translation>Перед закрывающей скобкой в выражениях</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="230"/>
        <source>After closing parenthesis in expressions</source>
        <translation>После закрывающей скобки в выражениях</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="240"/>
        <source>After JOIN keywords in FROM clause</source>
        <translation>После ключевых слов JOIN в операторе FROM</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="250"/>
        <source>Put each column constraint in CREATE TABLE into new line</source>
        <translation>Разместить каждое ограничение на столбец в отдельной строке в конструкции CREATE TABLE</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="260"/>
        <source>After comma</source>
        <translation>После запятой</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="270"/>
        <source>After comma in expressions</source>
        <translation>После запятой в выражениях</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="280"/>
        <source>After semicolon</source>
        <translation>После точки с запятой</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="290"/>
        <location filename="sqlenterpriseformatter.ui" line="512"/>
        <source>Never before semicolon</source>
        <translation>Никогда перед точкой с запятой</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="338"/>
        <source>White spaces</source>
        <translation>Пробелы</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="392"/>
        <source>Before comma in lists</source>
        <translation>Перед запятой в списках</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="402"/>
        <source>After comma in lists</source>
        <translation>После запятой в списках</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="412"/>
        <source>Before opening parenthesis</source>
        <translation>Перед открывающей скобкой</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="422"/>
        <source>After opening parenthesis</source>
        <translation>После открывающей скобки</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="432"/>
        <source>Before closing parenthesis</source>
        <translation>Перед закрывающей скобкой</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="442"/>
        <source>After closing parenthesis</source>
        <translation>После закрывающей скобки</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="452"/>
        <source>No space between SQL function name and opening parenthesis</source>
        <translation>Не ставить пробел между именем функции SQL и открывающкй скобкой</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="462"/>
        <source>Before dot operator (in path to database object)</source>
        <translation>Перед оператором &apos;.&apos; (в путях к объектам базы данных)</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="472"/>
        <source>After dot operator (in path to database object)</source>
        <translation>После оператора &apos;.&apos; (в путях к объектам базы данных)</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="482"/>
        <source>Before mathematical operator</source>
        <translation>Перед математическим оператором</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="492"/>
        <source>After mathematical operator</source>
        <translation>После математического оператора</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="502"/>
        <source>Never before comma</source>
        <translation>Никогда перед запятой</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="558"/>
        <source>Names</source>
        <translation>Имена</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="583"/>
        <source>Preferred name wrapper</source>
        <translation>Предпочитаемое обрамление имён</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="600"/>
        <source>Always use name wrapping</source>
        <translation>Всегда обрамлять имена</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="610"/>
        <source>Uppercase data type names</source>
        <translation>Приводить имена типов данных к верхнему регистру</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="620"/>
        <source>Uppercase keywords</source>
        <translation>Приводить ключевые слова к верхнему регистру</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="631"/>
        <source>Comments</source>
        <translation>Комментарии</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="637"/>
        <source>Preferred comment marker (where possible):</source>
        <translation>Предпочитаемый символ комментирования (где применимо):</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="647"/>
        <source>SqlEnterpriseFormatter.CommentMarkers</source>
        <translation>SqlEnterpriseFormatter.CommentMarkers</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="654"/>
        <source>Move all comments to the line end</source>
        <translation>Перемещать все комментарии в конец строки</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="664"/>
        <source>Line up comments at the line end</source>
        <translation>Выравнивать комментарии в конце строки</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="695"/>
        <source>Preview</source>
        <translation>Предпросмотр</translation>
    </message>
</context>
</TS>

==> sqlitestudio_3.1.0.orig.tar.gz: Plugins/SqlEnterpriseFormatter/SqlEnterpriseFormatter_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>QObject</name>
    <message>
        <location filename="sqlenterpriseformatter.cpp" line="91"/>
        <location filename="sqlenterpriseformatter.cpp" line="98"/>
        <source>name</source>
        <comment>example name wrapper</comment>
        <translation>имя</translation>
    </message>
</context>
<context>
    <name>SqlEnterpriseFormatter</name>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="46"/>
        <source>Indentation</source>
        <translation>Отступы</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="58"/>
        <source>Line up keywords in multi-line queries</source>
        <translation>Выравнивать ключевые слова в многострочных запросах</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="68"/>
        <source>Indent contents of parenthesis block</source>
        <translation>Выравнивать содержимое внутри скобок</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="91"/>
        <source>Tab size:</source>
        <translation>Шаг табуляции:</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="106"/>
        <source>New lines</source>
        <translation>Переносы строк</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="160"/>
        <source>Before opening parenthesis in column definitions</source>
        <translation>Перед открывающей скобкой в определениях столбцов</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="170"/>
        <source>After opening parenthesis in column definitions</source>
        <translation>После открывающей скобки в определениях столбцов</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="180"/>
        <source>Before closing parenthesis in column definitions</source>
        <translation>Перед закрывающей скобкой в определениях столбцов</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="190"/>
        <source>After closing parenthesis in column definitions</source>
        <translation>После закрывающей скобки в определениях столбцов</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="200"/>
        <source>Before opening parenthesis in expressions</source>
        <translation>Перед открывающей скобкой в выражениях</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="210"/>
        <source>After opening parenthesis in expressions</source>
        <translation>После открывающей скобки в выражениях</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="220"/>
        <source>Before closing parenthesis in expressions</source>
        <translation>Перед закрывающей скобкой в выражениях</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="230"/>
        <source>After closing parenthesis in expressions</source>
        <translation>После закрывающей скобки в выражениях</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="240"/>
        <source>After JOIN keywords in FROM clause</source>
        <translation>После ключевых слов JOIN в операторе FROM</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="250"/>
        <source>Put each column constraint in CREATE TABLE into new line</source>
        <translation>Разместить каждое ограничение на столбец в отдельной строке в конструкции CREATE TABLE</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="260"/>
        <source>After comma</source>
        <translation>После запятой</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="270"/>
        <source>After comma in expressions</source>
        <translation>После запятой в выражениях</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="280"/>
        <source>After semicolon</source>
        <translation>После точки с запятой</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="290"/>
        <location filename="sqlenterpriseformatter.ui" line="512"/>
        <source>Never before semicolon</source>
        <translation>Никогда перед точкой с запятой</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="338"/>
        <source>White spaces</source>
        <translation>Пробелы</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="392"/>
        <source>Before comma in lists</source>
        <translation>Перед запятой в списках</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="402"/>
        <source>After comma in lists</source>
        <translation>После запятой в списках</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="412"/>
        <source>Before opening parenthesis</source>
        <translation>Перед открывающей скобкой</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="422"/>
        <source>After opening parenthesis</source>
        <translation>После открывающей скобки</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="432"/>
        <source>Before closing parenthesis</source>
        <translation>Перед закрывающей скобкой</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="442"/>
        <source>After closing parenthesis</source>
        <translation>После закрывающей скобки</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="452"/>
        <source>No space between SQL function name and opening parenthesis</source>
        <translation>Не ставить пробел между именем функции SQL и открывающкй скобкой</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="462"/>
        <source>Before dot operator (in path to database object)</source>
        <translation>Перед оператором &apos;.&apos; (в путях к объектам базы данных)</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="472"/>
        <source>After dot operator (in path to database object)</source>
        <translation>После оператора &apos;.&apos; (в путях к объектам базы данных)</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="482"/>
        <source>Before mathematical operator</source>
        <translation>Перед математическим оператором</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="492"/>
        <source>After mathematical operator</source>
        <translation>После математического оператора</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="502"/>
        <source>Never before comma</source>
        <translation>Никогда перед запятой</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="558"/>
        <source>Names</source>
        <translation>Имена</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="583"/>
        <source>Preferred name wrapper</source>
        <translation>Предпочитаемое обрамление имён</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="600"/>
        <source>Always use name wrapping</source>
        <translation>Всегда обрамлять имена</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="610"/>
        <source>Uppercase data type names</source>
        <translation>Приводить имена типов данных к верхнему регистру</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="620"/>
        <source>Uppercase keywords</source>
        <translation>Приводить ключевые слова к верхнему регистру</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="631"/>
        <source>Comments</source>
        <translation>Комментарии</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="637"/>
        <source>Preferred comment marker (where possible):</source>
        <translation>Предпочитаемый символ комментирования (где применимо):</translation>
    </message>
    <message>
        <source>SqlEnterpriseFormatter.CommentMarkers</source>
        <translation type="obsolete">SqlEnterpriseFormatter.CommentMarkers</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="654"/>
        <source>Move all comments to the line end</source>
        <translation>Перемещать все комментарии в конец строки</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="664"/>
        <source>Line up comments at the line end</source>
        <translation>Выравнивать комментарии в конце строки</translation>
    </message>
    <message>
        <location filename="sqlenterpriseformatter.ui" line="695"/>
        <source>Preview</source>
        <translation>Предпросмотр</translation>
    </message>
</context>
</TS>
